from setuptools import setup

setup(name='gaus-bi-dist',
      version='0.1',
      description='Gaussian Distributions and Binomial Distributions',
      packages=['gaus-bi-dist'],
      zip_safe=False)
